@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2013, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -26,6 +26,5 @@ import org.ddogleg.struct.FastQueue;
 public class Node<N,E>
 {
    N data;
-   FastQueue<Edge<N,E>> edges = new FastQueue<Edge<N, E>>((Class)Edge.class,false);
-
+   FastQueue<Edge<N,E>> edges = new FastQueue<>(Edge<N,E>::new);
 }
